abacusai.eda_feature_collinearity — AbacusAI documentation

# abacusai.eda_feature_collinearity

## Classes

`EdaFeatureCollinearity` | Eda Collinearity of the latest version of the data for a given feature.

## Module Contents

class abacusai.eda_feature_collinearity.EdaFeatureCollinearity(client, selectedFeature=None, sortedColumnNames=None, featureCollinearity=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Collinearity of the latest version of the data for a given feature.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - selectedFeature (str) – Selected feature to show the collinearity

    - sortedColumnNames (list) – Name of all the features in the data sorted in descending order of collinearity value

    - featureCollinearity (dict) – A dict describing the collinearity between a given feature and all the features in the data

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict